# -*- coding: utf-8 -*-
"""Project metadata

Information describing the project.
"""

# The package name, which is also the "UNIX name" for the project.
package = 'btsbots-wallet'
project = "web wallet for BitShares"
project_no_spaces = project.replace(' ', '')
version = '0.1.2'
description = 'web wallet for BitShares'
authors = ['Alt']
authors_string = ', '.join(authors)
emails = ['pch957@163.com']
license = 'PRIVATE'
copyright = '2015 ' + authors_string
url = 'https://btsbots.com/'
